## 同花顺板块指数行情

接口：ths_daily

描述：获取同花顺板块指数行情。注：数据版权归属同花顺，如做商业用途，请主动联系同花顺，如需帮助请联系微信：waditu_a

限量：单次最大3000行数据（需6000积分），可根据指数代码、日期参数循环提取。

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 指数代码 |
| trade_date | str | N | 交易日期（YYYYMMDD格式，下同） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | TS指数代码 |
| trade_date | str | Y | 交易日 |
| close | float | Y | 收盘点位 |
| open | float | Y | 开盘点位 |
| high | float | Y | 最高点位 |
| low | float | Y | 最低点位 |
| pre_close | float | Y | 昨日收盘点 |
| avg_price | float | Y | 平均价 |
| change | float | Y | 涨跌点位 |
| pct_change | float | Y | 涨跌幅 |
| vol | float | Y | 成交量 |
| turnover_rate | float | Y | 换手率 |
| total_mv | float | N | 总市值 |
| float_mv | float | N | 流通市值 |

接口示例

```python
pro = ts.pro_api()

df = pro.ths_daily(ts_code='865001.TI', start_date='20200101', end_date='20210101', fields='ts_code,trade_date,open,close,high,low,pct_change')
```

数据样例

```python
ts_code trade_date      close       open       high        low pct_change           vol
0    865001.TI   20201231  1664.7530  1660.7060  1671.2290  1649.4200     0.5646  13224.260000
```